from os import getcwd
import json
from random import choice
from PyDictionary import PyDictionary


def get_info(word):
    dictionary = PyDictionary()
    
    # gets synonyms
    synonyms_list = dictionary.synonym(word)
    synonyms = ""
    for synonym in synonyms_list[3:5]:
        synonyms += (synonym + ", ")
    
    # get antonyms
    antonyms_list = dictionary.antonym(word)
    antonyms = ""
    for antonym in antonyms_list[3:5]:
        antonyms += (antonym + ", ")

    return "Synonyms: "+ synonyms + "\n\n" + "Antonyms: " + antonyms
def get_word(path):
    words_data = open(path, "r")
    words = words_data.read().split("\n")
    random_word = choice(words)
    return random_word

def get_path():
    working_dir_path = getcwd().replace("\\", "\\\\")
    full_path = working_dir_path + "\\notify_vocab\\assets\\words.txt" # replace it with your path

    return full_path

path = get_path()
random_word = get_word(path)
info = get_info(random_word)
    
    

    
    


from get_words import random_word
from get_words import info
from plyer import notification
import time

def notify_vocab( timeout, word="animal", info="something in the wild"):

    notification.notify(
        title=word,
        message=info,
        app_icon="notify_vocab\\assets\\dictionary.ico",
        timeout=timeout
    )

def notifyVocab(timeout=5):
    notify_vocab(timeout,random_word,info)

notifyVocab()




from setuptools import setup, find_packages

VERSION = '0.1.2'
DESCRIPTION = 'a small library that notifies you of a new word and its meaning every time you run it'
LONG_DESCRIPTION = 'You can customize it a little bit by using task shedular so that you can get to learn a new word (every let`s say one hour)'

# Setting up
setup(
    name="notifyVocab",
    version=VERSION,
    author="Mohammad Tayyib",
    author_email="tayyibsofi@gmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['PyDictionary', 'plyer'],
    keywords=['python', 'random-words', 'vocab', 'vocabulary', 'notification'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)